@@ -70,4 +70,4 @@ def sha256(filename: str) -> str:
 
             return sha256_obj.hexdigest()
     else:
-        return ''
+        return 'Invalid File'
